#!/usr/bin/env python
#
# This file is part of Road Trip
# Author(s): Amanda Salazar, Girlstart
# Copyright 2008
#
# Source code is derived from Girlstart's Project IT Girl Game Templates:
# http://itgirl.dreamhosters.com/itgirlgames/, http://www.girlstart.org/itgirl
# See the credits file for image sources.
#
# Road Trip is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Road Trip is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Road Trip.  If not, see <http://www.gnu.org/licenses/>.

import pygame, random
from helpers import *

class Player(pygame.sprite.Sprite):
    # This is our player that will move around the screen controlled by the user
    
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if image == None:
            self.image, self.rect = load_image('player24car.png',-1)
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint

        # Initialize the number of pellets eaten
        self.pellets = 0
        
        # Set the number of Pixels to move each time
        self.x_dist = 10
        self.y_dist = 10 

    def update(self,key,block_group):
        xMove,yMove = 0,0
        


        if (key == K_RIGHT):
            xMove += self.x_dist
        elif (key == K_LEFT):
            xMove += -self.x_dist
        elif (key == K_UP):
            yMove += -self.y_dist
        elif (key == K_DOWN):
            yMove += self.y_dist

        self.rect.move_ip(xMove,yMove)

        # If we hit a block, don't move - reverse the movement
        if pygame.sprite.spritecollide(self, block_group, False):
            self.rect.move_ip(-xMove,-yMove)

    def dead_end(self,block_group):
        allowed_moves = 4

        # try moving right
        self.rect.move_ip(self.x_dist,0)
        if pygame.sprite.spritecollide(self, block_group, False): # blocked by a wall
            allowed_moves -= 1
        self.rect.move_ip(-self.x_dist,0)

        # try moving left
        self.rect.move_ip(-self.x_dist,0)
        if pygame.sprite.spritecollide(self, block_group, False): # blocked by a wall
            allowed_moves -= 1
        self.rect.move_ip(self.x_dist,0)

        # try moving up
        self.rect.move_ip(0,-self.y_dist)
        if pygame.sprite.spritecollide(self, block_group, False): # blocked by a wall
            allowed_moves -= 1
        self.rect.move_ip(0,self.y_dist)

        # try moving down
        self.rect.move_ip(0,self.y_dist)
        if pygame.sprite.spritecollide(self, block_group, False): # blocked by a wall
            allowed_moves -= 1
        self.rect.move_ip(0,-self.y_dist)

        if allowed_moves <= 1: # blocked by a wall in at least 3 directions
            return True
        else:
            return False
        
    def generateQuestion(self, background, screen):
        questionbackground, questionrect = load_image("questionbackground.png")
        questionrect.center = 400, 350
        #answer1, answer1rect = load_image("one.png")
        #answer2, answer2rect = load_image("two.png")
        answer3, answer3rect = load_image("answer1.png")
        #answer1rect.center = 100,400
        #answer2rect.center = 200,400
        answer3rect.center = 550,550

        self.screen = screen
        self.background = background
        
        activity_completed = False
        while not activity_completed:
            screen.blit(questionbackground, questionrect)
            screen.blit(answer3, answer3rect)
            pygame.display.flip()
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    sys.exit()
                elif event.type==pygame.MOUSEBUTTONDOWN: 
                    if answer3rect.collidepoint(event.pos):
                        activity_completed= True
                    
            # Ask our question until they get it right
            #if self.askQuestion(question, answer3, answer3rect, answer3rect):
            #    activity_completed = True

    def askQuestion(self, questionText, answer3, answer3rect, correctAnswerrect):
        # questionText is the string of the question
        # answer1, answer2 and answer3 are the possible answers for the user to choose
        # answer1rect, answer2rect and answer3rect are the Rects that describe where the images for
        # the answers need to be drawn.
        # correctAnswer is the correct answer
        
        # Set up the font for our question.  Redraw the background first to clear the screen
        self.screen.blit(self.background, (0, 0))
        font = pygame.font.Font(None, 30)
        #text = font.render(questionText, 1, (255, 0, 0))
        textrect = text.get_rect()
        textrect.centerx, textrect.centery = 200,200
        self.screen.blit(text, textrect)
        
        # Draw our answers to the screen
        #self.screen.blit(answer1, answer1rect)
        #self.screen.blit(answer2, answer2rect)
        self.screen.blit(answer3, answer3rect)
        
        pygame.display.flip()
        
        # Now let's loop waiting for the user's answer
        answered = False
        while not answered:
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    sys.exit()
                elif event.type == pygame.MOUSEBUTTONDOWN:
                        if answer1rect.collidepoint(event.pos):
                            # If we're here, then the user has clicked on one of the answers.
                            answered = True
                            if answer1rect == correctAnswerrect:
                                # User answered correctly, let them know
                                correct = True
                            else:
                                correct = False
                        elif answer2rect.collidepoint(event.pos):
                            answered = True
                            if answer2rect == correctAnswerrect:
                                correct = True
                            else:
                                correct = False
                        elif answer3rect.collidepoint(event.pos):
                            answered = True
                            if answer3rect == correctAnswerrect:
                                correct = True
                            else:
                                correct = False				
        
        if correct:
            text = font.render("Correct!  Press any key to continue", 1, (255,255,255))
        else:
            text = font.render("Sorry, that's not correct.  Press any key to continue", 1, (255,255,255))
        
        self.screen.blit(self.background, (0, 0))
        textrect = text.get_rect()
        textrect.centerx, textrect.centery = 250,75
        self.screen.blit(text, textrect)
        
        pygame.display.flip()
        
        # Now, wait for the user to click a key to continue:
        answered = False
        while not answered:
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    sys.exit()
                elif event.type == pygame.KEYDOWN:
                    answered = True				
        
        return correct
    
class Monster(pygame.sprite.Sprite):
    # This is our Monster that will move around the screen randomly
    
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if image == None:
            self.image, self.rect = load_image('Beer_mug.png',-1)
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint

        # Initialize the direction and speed:
        self.direction = random.randint(1,4)
        self.speed = 1 # how many pixels to move each time
        self.moves = random.randint(50,100)
        self.moveCount = 0
            
    def update(self,block_group,block_group2=None):
        xMove,yMove = 0,0
        
        if self.direction==1:
            xMove = -self.speed
        elif self.direction==2:
            yMove = -self.speed
        elif self.direction==3:
            xMove = self.speed
        elif self.direction==4:
            yMove = self.speed
        
        self.rect.move_ip(xMove,yMove)
        self.moveCount += 1
        
               
        if pygame.sprite.spritecollideany(self, block_group) or pygame.sprite.spritecollideany(self, block_group2):
            # If we hit a block or finish line, don't move - reverse the movement
            self.rect.move_ip(-xMove,-yMove)
            self.direction = random.randint(1,4)
        elif self.moves == self.moveCount:
            # If we have moved enough, choose a new direction
            self.direction = random.randint(1,4)
            self.moves = random.randint(50,100)
            self.moveCount = 0


# Check for a player/monster collision
    #for m in pygame.sprite.spritecollide(monster, False):
    #    player.generateQuestion(background, screen)
    #    Monster.remove(m)



class Block(pygame.sprite.Sprite):
        
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if image == None:
            self.image, self.rect = load_image('block.png',-1)
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint

class Space(pygame.sprite.Sprite):
        
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if image == None:
            self.image, self.rect = load_image('space.png',-1)
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint

class FinishLine(pygame.sprite.Sprite):
        
    def __init__(self, centerPoint, image = None):
        pygame.sprite.Sprite.__init__(self) 
        
        if image == None:
            self.image, self.rect = load_image('finish.png')
        else:
            self.image = image
            self.rect = image.get_rect()
        self.rect.center = centerPoint
